@@ -1,7 +1,7 @@
 # Copyright (c) 2020 Adam Souzis
 # SPDX-License-Identifier: MIT
-from ..util import saveToFile, UnfurlTaskError
-from .shell import ShellConfigurator, which
+from ..util import saveToFile, UnfurlTaskError, wrap_var
+from .shell import ShellConfigurator
 from ..support import getdir, abspath, Status, writeFile
 import json
 import os
@@ -98,11 +98,12 @@ class TerraformConfigurator(ShellConfigurator):
             return None
 
         try:
-            providerSchema = json.loads(result.stdout.strip())["provider_schemas"]
+            providerSchema = json.loads(result.stdout.strip())
             # XXX add to ensemble "lock" section
             # os.path.join(env['TF_DATA_DIR'], "modules", "modules.json")
             # os.path.join(env['TF_DATA_DIR'], "plugins", "plugins.json")
-            return providerSchema
+            # missing if there are no providers:
+            return providerSchema.get("provider_schemas", {})
         except:
             task.logger.debug("failed to load provider schema", exc_info=True)
             return None
@@ -185,10 +186,10 @@ class TerraformConfigurator(ShellConfigurator):
                 providerSchema = json.load(psf)
         else:  # first time
             providerSchema = self._initTerraform(task, terraform, cwd, env)
-            if providerSchema:
+            if providerSchema is not None:
                 saveToFile(providerSchemaPath, providerSchema)
             else:
-                raise UnfurlTaskError(task, "terraform init failed")
+                raise UnfurlTaskError(task, "terraform init failed in %s" % cwd)
 
         planPath = self._getPlanPath(task, ctx)
         # build the command line and run it
@@ -231,7 +232,7 @@ class TerraformConfigurator(ShellConfigurator):
                     cmd, timeout=task.configSpec.timeout, env=env, cwd=cwd, echo=echo
                 )
             else:
-                raise UnfurlTaskError(task, "terrform init failed")
+                raise UnfurlTaskError(task, "terrform init failed in %s" % cwd)
 
         # process the result
         status = None
@@ -248,14 +249,21 @@ class TerraformConfigurator(ShellConfigurator):
             state = markSensitive(providerSchema, state, task, self.sensitiveNames)
             # save state file in home as yaml, encrypting sensitive values
             writeFile(ctx, state, "terraform.tfstate.yaml", "home")
-            outputs = {name: attrs["value"] for name, attrs in state["outputs"].items()}
+            outputs = {
+                name: wrap_var(attrs["value"])
+                for name, attrs in state["outputs"].items()
+            }
             state.update(result.__dict__)
+            state["outputs"] = outputs  # replace outputs
             self.processResultTemplate(task, state)
         else:
             outputs = None
 
-        # XXX is there a "Changing..." to check for?
-        modified = "Creating..." in result.stdout or "Destroying..." in result.stdout
+        modified = (
+            "Modifying..." in result.stdout
+            or "Creating..." in result.stdout
+            or "Destroying..." in result.stdout
+        )
         yield task.done(
             success, modified, status, result=result.__dict__, outputs=outputs
         )
