@@ -141,7 +141,7 @@ def writeEnsembleManifest(
         specDir = os.path.abspath(specDir)
     else:
         specDir = ""
-    vars = dict(specRepoUrl=specRepo.getGitLocalUrl(specDir, "spec"))
+    vars = dict(specRepoUrl=specRepo.getUrlWithPath(specDir))
     if extraVars:
         vars.update(extraVars)
     return writeTemplate(destDir, manifestName, "manifest.yaml.j2", vars, templateDir)
@@ -239,6 +239,11 @@ def createProject(
         repo = Repo.findContainingRepo(projectdir)
         if not repo:
             raise UnfurlError("Could not find an existing repository")
+        if not repo.repo.head.is_valid():
+            raise UnfurlError(
+                "Existing repository is empty: unable to create project in empty git repositories"
+            )
+
     else:
         repo = None
 
@@ -355,6 +360,8 @@ def _getEnsemblePaths(sourcePath, sourceProject):
     # so if sourcePath was a directory try for one of the default template files
     if isServiceTemplate or os.path.isdir(sourcePath):
         # look for an ensemble-template or service-template in source path
+        if os.path.isdir(os.path.join(sourcePath, DefaultNames.ProjectDirectory)):
+            sourcePath = os.path.join(sourcePath, DefaultNames.ProjectDirectory)
         template = _looksLike(sourcePath, DefaultNames.EnsembleTemplate)
         if template:
             sourceDir = sourceProject.getRelativePath(template[0])
