@@ -91,6 +91,11 @@ class Project(object):
         current = os.path.abspath(testPath)
         while current and current != os.sep:
             test = os.path.join(current, DefaultNames.LocalConfig)
+            if os.path.exists(test):
+                return test
+            test = os.path.join(
+                current, DefaultNames.ProjectDirectory, DefaultNames.LocalConfig
+            )
             if os.path.exists(test):
                 return test
             current = os.path.dirname(current)
@@ -357,7 +362,10 @@ class LocalConfig(object):
                     break
             else:
                 # if project isn't already in projects, use generated name
-                name = "_" + os.path.basename(project.projectRoot)
+                # XXX need to replace characters that don't match our namedObjects pattern manifest-schema.json
+                dirname, name = os.path.split(project.projectRoot)
+                if name == DefaultNames.ProjectDirectory:
+                    name = os.path.basename(dirname)
                 counter = 0
                 while name in self.projects:
                     counter += 1
@@ -541,11 +549,15 @@ class LocalEnv(object):
                 if os.path.exists(test):
                     return self.getProject(test, self.homeProject)
                 else:
-                    message = (
-                        "Can't find an Unfurl ensemble or project in folder '%s'"
-                        % manifestPath
-                    )
-                    raise UnfurlError(message)
+                    test = os.path.join(manifestPath, DefaultNames.ProjectDirectory)
+                    if os.path.exists(test):
+                        return self.getProject(test, self.homeProject)
+                    else:
+                        message = (
+                            "Can't find an Unfurl ensemble or project in folder '%s'"
+                            % manifestPath
+                        )
+                        raise UnfurlError(message)
         else:
             return manifestPath
 
@@ -577,6 +589,10 @@ class LocalEnv(object):
             if os.path.exists(test):
                 return self.getProject(test, self.homeProject)
 
+            test = os.path.join(current, DefaultNames.ProjectDirectory)
+            if os.path.exists(test):
+                return self.getProject(test, self.homeProject)
+
             current = os.path.dirname(current)
 
         message = "Can't find an Unfurl ensemble or project in the current directory (or any of the parent directories)"
