@@ -184,6 +184,7 @@ class Manifest(AttributeManager):
 
         configChange = ConfigChange()
         Manifest.loadStatus(changeSet, configChange)
+        # XXX update to latest schema but only what we need
         configChange.changeId = changeSet.get("changeId", 0)
         configChange.parentId = changeSet.get("parentId")
 
@@ -355,14 +356,14 @@ class Manifest(AttributeManager):
     def addRepository(self, repo, toscaRepository, file_name):
         repository = self.repositories.get(toscaRepository.name)
         if repository:
+            repo = repo or repository.repo
             if (
                 repository.repo and repository.repo != repo
             ) or repository.repository.tpl != toscaRepository.tpl:
                 raise UnfurlError(
                     'Repository "%s" already defined' % toscaRepository.name
                 )
-            repository = RepoView(toscaRepository, repo, file_name)
-        self.repositories[repository.name] = repository
+        self.repositories[repository.name] = RepoView(toscaRepository, repo, file_name)
         return repository
 
     def updateRepositories(self, config, inlineRepositories=None):
@@ -398,7 +399,7 @@ class Manifest(AttributeManager):
             # this is called too early to use self.getBaseDir()
             path = getBaseDir(self.path) if self.path else "."
             if self.repo:
-                url = self.repo.getGitLocalUrl(path, "self")
+                url = self.repo.getUrlWithPath(path)
                 path = os.path.relpath(path, self.repo.workingDir)
             else:
                 url = "file:" + path
@@ -422,7 +423,7 @@ class Manifest(AttributeManager):
                 path = self.localEnv.project.projectRoot
                 if repo:
                     assert path
-                    url = repo.getGitLocalUrl(path, "spec")
+                    url = repo.getUrlWithPath(path)
                     path = os.path.relpath(path, repo.workingDir)
                 else:
                     url = "file:" + path
@@ -438,7 +439,13 @@ class Manifest(AttributeManager):
         return {name: repo.repository.tpl for name, repo in self.repositories.items()}
 
     def loadYamlInclude(
-        self, yamlConfig, templatePath, baseDir, warnWhenNotFound=False
+        self,
+        yamlConfig,
+        templatePath,
+        baseDir,
+        warnWhenNotFound=False,
+        expanded=None,
+        check=False,
     ):
         """
         This is called while the YAML config is being loaded.
@@ -456,13 +463,27 @@ class Manifest(AttributeManager):
                 # replace spec with just its name
                 artifactTpl["repository"] = reponame
                 inlineRepository = repo
-            artifact = Artifact(artifactTpl, path=baseDir)
         else:
-            artifact = Artifact(dict(file=templatePath), path=baseDir)
+            artifactTpl = dict(file=templatePath)
+
+        if check:
+            if not inlineRepository and "repository" in artifactTpl:
+                reponame = artifactTpl["repository"]
+                if reponame in ["spec", "self", "unfurl"]:  # builtin
+                    return True
+                repositories = self._getRepositories(expanded)
+                return reponame in repositories
+            return True
+
+        artifact = Artifact(artifactTpl, path=baseDir)
+
+        extraRepos = []
+        if inlineRepository:
+            extraRepos.append(inlineRepository)
 
         tpl = CommentedMap()
         tpl["repositories"] = self.updateRepositories(
-            yamlConfig.config, [inlineRepository] if inlineRepository else []
+            expanded or yamlConfig.config, extraRepos
         )
         loader = toscaparser.imports.ImportsLoader(
             None,
