@@ -6,7 +6,8 @@ import git
 from git.repo.fun import is_git_dir
 import logging
 from six.moves.urllib.parse import urlparse
-from unfurl.util import UnfurlError
+from .util import UnfurlError
+from . import getLogLevel
 import toscaparser.repositories
 from ruamel.yaml.comments import CommentedMap
 
@@ -60,7 +61,7 @@ def splitGitUrl(url):
 class _ProgressPrinter(git.RemoteProgress):
     def update(self, op_code, cur_count, max_count=None, message=""):
         # print update to stdout but only if logging is INFO or more verbose
-        if message and logger.getEffectiveLevel() <= logging.INFO:
+        if message and getLogLevel() <= logging.INFO:
             print("fetching from %s, received: %s " % (self.gitUrl, message))
 
 
@@ -168,12 +169,7 @@ class Repo(object):
             kwargs = dict(recurse_submodules=True)
             if revision:
                 kwargs["branch"] = revision
-            repo = git.Repo.clone_from(
-                gitUrl,
-                localRepoPath,
-                progress,
-                **kwargs
-            )
+            repo = git.Repo.clone_from(gitUrl, localRepoPath, progress, **kwargs)
         except git.exc.GitCommandError as err:
             raise UnfurlError(
                 "couldn't create working dir, clone failed: " + err._cmdline
@@ -287,6 +283,8 @@ class GitRepo(Repo):
 
     @property
     def revision(self):
+        if not self.repo.head.is_valid():
+            return ""
         return self.repo.head.commit.hexsha
 
     def resolveRevSpec(self, revision):
@@ -300,7 +298,7 @@ class GitRepo(Repo):
             if os.path.isabs(path):
                 # get path relative to repository's root
                 path = os.path.relpath(path, self.workingDir)
-            return self.url + "#:" + path
+            return normalizeGitUrl(self.url) + "#:" + path
         else:
             return self.getGitLocalUrl(path)
 
@@ -379,6 +377,8 @@ class GitRepo(Repo):
         return success
 
     def getInitialRevision(self):
+        if not self.repo.head.is_valid():
+            return ""  # an uninitialized repo
         firstCommit = next(self.repo.iter_commits("HEAD", max_parents=0))
         return firstCommit.hexsha
 
