@@ -23,6 +23,7 @@ def serializeValue(value, **kw):
 
 class ResourceRef(object):
     # ABC requires 'parent', and '_resolve'
+    _templar = None
 
     def _getProp(self, name):
         if name == ".":
@@ -517,6 +518,11 @@ class ResultsMap(Results, MutableMapping):
             if isinstance(v, Result)
         )
 
+    def getResolved(self):
+        return dict(
+            (key, v) for key, v in self._attributes.items() if isinstance(v, Result)
+        )
+
     def __contains__(self, key):
         return key in self._attributes
 
