@@ -12,7 +12,7 @@ import six
 import re
 import ast
 import codecs
-from enum import IntEnum
+from enum import IntEnum, Enum
 
 from .eval import RefContext, setEvalFunc, Ref, mapValue
 from .result import Results, ResultsMap, Result, ExternalValue, serializeValue
@@ -26,6 +26,8 @@ from .util import (
     saveToTempfile,
     saveToFile,
     isSensitive,
+    loadModule,
+    loadClass,
 )
 from .merge import intersectDict, mergeDicts
 import ansible.template
@@ -53,6 +55,14 @@ Priority = IntEnum(
 )
 
 
+class Reason(object):
+    pass
+
+
+for r in "add reconfigure force upgrade update missing error degraded prune".split():
+    setattr(Reason, r, r)
+
+
 class Defaults(object):
     shouldRun = Priority.required
     workflow = "deploy"
@@ -208,7 +218,9 @@ def _getbaseDir(ctx, name=None):
     "tmp":   A temporary directory for the instance (removed after unfurl exits)
     "spec.src": The directory of the source file the current instance's template appears in.
     "spec.home": The "home" directory of the source file the current instance's template.
-    "spec.local": The "local" directory of the source file the current instance's template.
+    "spec.local": The "local" directory of the source file the current instance's template
+    "project": The root directory of the current project.
+    "unfurl.home": The location of home project (UNFURL_HOME).
 
     Otherwise look for a repository with the given name and return its path or None if not found.
     """
@@ -227,6 +239,8 @@ def _getbaseDir(ctx, name=None):
         return os.path.join(instance.baseDir, instance.name, "local")
     elif name == "project":
         return instance.template.spec._getProjectDir() or instance.baseDir
+    elif name == "unfurl.home":
+        return instance.template.spec._getProjectDir(True) or instance.baseDir
     else:
         start, sep, rest = name.partition(".")
         if sep:
@@ -270,6 +284,34 @@ setEvalFunc("abspath", lambda arg, ctx: abspath(ctx, *_mapArgs(arg, ctx)))
 setEvalFunc("get_dir", lambda arg, ctx: getdir(ctx, *_mapArgs(arg, ctx)))
 
 
+def evalPython(arg, ctx):
+    """
+    eval:
+      python: path/to/src.py#func
+
+    or
+
+    eval:
+      python: mod.func
+
+    Where ``func`` is python function that receives a `RefContext` argument.
+    If path is a relative, it will be treated as relative to the current source file.
+    """
+    arg = mapValue(arg, ctx)
+    if "#" in arg:
+        path, sep, fragment = arg.partition("#")
+        # if path is relative, treat as relative to current src location
+        path = abspath(ctx, path, "src", False)
+        mod = loadModule(path)
+        funcName = mod.__name__ + "." + fragment
+    else:
+        funcName = arg
+    func = loadClass(funcName)
+    return func(ctx)
+
+
+setEvalFunc("python", evalPython)
+
 # XXX need an api check if an object was marked sensitive
 # _secrets = weakref.WeakValueDictionary()
 # def addSecret(secret):
