@@ -5,9 +5,10 @@ TOSCA implementation
 """
 from .tosca_plugins import TOSCA_VERSION
 from .util import UnfurlError, UnfurlValidationError, getBaseDir
-from .eval import Ref, RefContext
+from .eval import Ref, RefContext, mapValue
 from .result import ResourceRef, ResultsList
 from .merge import patchDict
+from . import getLogLevel
 from toscaparser.tosca_template import ToscaTemplate
 from toscaparser.properties import Property
 from toscaparser.elements.entity_type import EntityType
@@ -97,9 +98,14 @@ class ToscaSpec(object):
                     )
 
         matches = list(_findMatches())
-        return [
-            patchDict(m[0].toscaEntityTemplate.entity_tpl, m[1], True) for m in matches
-        ]
+
+        def _patch(m):
+            node = m[0]
+            tpl = node.toscaEntityTemplate.entity_tpl
+            patch = mapValue(m[1], RefContext(node, dict(template=tpl)))
+            return patchDict(tpl, patch, True)
+
+        return [_patch(m) for m in matches]
 
     def _parseTemplate(self, path, inputs, toscaDef, resolver):
         # need to set a path for the import loader
@@ -173,7 +179,7 @@ class ToscaSpec(object):
                     ExceptionCollector.exceptions[:0] = errorsSoFar
                     message = "\n".join(
                         ExceptionCollector.getExceptionsReport(
-                            logger.getEffectiveLevel() < logging.INFO
+                            getLogLevel() < logging.INFO
                         )
                     )
                     raise UnfurlValidationError(
@@ -185,9 +191,7 @@ class ToscaSpec(object):
 
             if ExceptionCollector.exceptionsCaught():
                 message = "\n".join(
-                    ExceptionCollector.getExceptionsReport(
-                        logger.getEffectiveLevel() < logging.INFO
-                    )
+                    ExceptionCollector.getExceptionsReport(getLogLevel() < logging.INFO)
                 )
                 raise UnfurlValidationError(
                     "TOSCA validation failed for %s: \n%s" % (path, message),
@@ -200,12 +204,16 @@ class ToscaSpec(object):
             return None
         return getBaseDir(self.template.path)
 
-    def _getProjectDir(self):
+    def _getProjectDir(self, home=False):
         # hacky
         if self.template.import_resolver:
             manifest = self.template.import_resolver.manifest
-            if manifest.localEnv and manifest.localEnv.project:
-                return manifest.localEnv.project.projectRoot
+            if manifest.localEnv:
+                if home:
+                    if manifest.localEnv.homeProject:
+                        return manifest.localEnv.homeProject.projectRoot
+                elif manifest.localEnv.project:
+                    return manifest.localEnv.project.projectRoot
         return None
 
     def addNodeTemplate(self, name, tpl):
@@ -697,7 +705,14 @@ class RelationshipSpec(EntitySpec):
                     self.capability = c
                     break
             else:
-                raise UnfurlError('capability %s not found in %s for %s' % (template.capability.name, [c.name for c in targetNode.capabilities.values()], targetNode.name))
+                raise UnfurlError(
+                    "capability %s not found in %s for %s"
+                    % (
+                        template.capability.name,
+                        [c.name for c in targetNode.capabilities.values()],
+                        targetNode.name,
+                    )
+                )
 
     @property
     def source(self):
